from cfg_checker.common import logger_cli
from cfg_checker.helpers import args_utils

import checker

command_help = "Network infrastructure checks and reports"


def init_parser(_parser):
    # network subparser
    net_subparsers = _parser.add_subparsers(dest='type')

    net_check_parser = net_subparsers.add_parser(
        'check',
        help="Do network check and print the result"
    )

    net_check_parser.add_argument(
        '--detailed',
        action="store_true", default=False,
        help="Print error details after summary"
    )

    net_report_parser = net_subparsers.add_parser(
        'report',
        help="Generate network check report"
    )

    net_report_parser.add_argument(
        '--html',
        metavar='network_html_filename',
        help="HTML filename to save report"
    )

    return _parser


def _prepare_check():
    _checker_class = checker.NetworkChecker()
    _checker_class.collect_reclass_networks()
    _checker_class.collect_network_info()
    return _checker_class


def _prepare_map():
    _map_class = None

    return _map_class


def do_check(args):
    # Net Checks
    # should not print map, etc...
    # Just bare summary and errors
    logger_cli.info("# Network check to console")
    netChecker = _prepare_check()
    netChecker.print_network_report()

    # save what was collected
    netChecker.errors.save_iteration_data()

    # print a report
    netChecker.print_summary()

    # if set, print details
    if args.detailed:
        netChecker.print_error_details()


def do_report(args):
    # Network Report
    # should generate Static HTML page
    # with node/network map and values

    logger_cli.info("# Network report (check, node map")

    _filename = args_utils.get_arg(args, 'html')

    netChecker = _prepare_check()
    netChecker.create_html_report(_filename)

    return


def do_map(args):
    # Network Map
    # Should generate network map to console or HTML
    logger_cli.info("# Network report")

    _type, _filename = args_utils.get_network_map_type_and_filename(args)
    # networkMap = _prepare_map

    # TODO: Create map class to generate network map

    return


def do_ping(args):
    # Network pinger
    # Checks if selected nodes are pingable
    # with a desireble parameters: MTU, Frame, etc

    # TODO: Simple ping based on parameters

    return


def do_trace(args):
    # Network packet tracer
    # Check if packet is delivered to proper network host

    # TODO: Packet tracer

    return
